@@ -267,6 +267,7 @@ int CatHandler::findEntry(KPath what)
    int ret;
 
    item_name=what.pop();
+
    setCurrentBranch(what);
 
    ce=catalog.first();
@@ -609,10 +610,7 @@ uint CatHandler::scanDir(const char *cur_dir, KPath cur_path)
 {
    QDir current_dir(cur_dir,0,QDir::DirsFirst+QDir::Name);
 
-   if (!current_dir.isReadable())
-   {
-      return 0;
-   }
+   if (!current_dir.isReadable()) return 0;
 
    const QFileInfoList *files= current_dir.entryInfoList();
    QFileInfoListIterator files_it(*files);
@@ -620,24 +618,25 @@ uint CatHandler::scanDir(const char *cur_dir, KPath cur_path)
    CatEntry *ce;
    int et;
    QString *str;
-   QString new_dir;
-   uint total_size=0;
-   uint subdir_size;
-   QString mstr;
-   QString desc;
+   uint total_size=0, subdir_size;
+   QString mstr, desc, new_dir;
+   bool new_branch_made=false;
 
    mstr=i18n("Scanning directory: ");
    mstr+=cur_dir;
    mstr+="...";
    micro(&mstr);
 
-   newBranch(cur_path);
-
    while ((f=files_it.current()) != 0)
    {
       ++files_it;
       if (f->fileName() != "." && f->fileName() != "..")
       {
+      	if (!new_branch_made)
+      	{
+     		   newBranch(cur_path);
+     		   new_branch_made=true;
+      	}
          if (f->isDir()) et=CatEntry::E_DIR;
             else         et=CatEntry::E_FILE;
          if (f->isSymLink()) et+=CatEntry::E_LINK;
